<?php

class purl_domain_or_path implements purl_processor {
  var $_processor = FALSE;
  var $_processor_info = array();

  public function __construct() {
    global $base_url;

    // Set vars.
    $this->_processor_info['url'] = str_ireplace(array('http://', 'https://'), '', $base_url);
    $this->_processor_info['uri'] =  explode('/', request_path());

    // Check if Purl Domain is available and domains exists in DB.
    if (class_exists('purl_domain') &&
      ($gid = $this->query($this->_processor_info['url'])) == TRUE) {
      $this->_processor_info['gid'] = $gid;
      $this->_processor_info['type'] = 'domain';
    }

    // Set Purl Path case Domains fail validation.
    if (class_exists('purl_path') && isset($this->_processor_info['uri'][0]) &&
      ($gid = $this->query($this->_processor_info['uri'][0])) == TRUE) {
      $this->_processor_info['gid'] = $gid;
      $this->_processor_info['type'] = 'path';
    }

    $this->_processor = isset($this->_processor_info['type']) ?
      purl_get_processor($this->_processor_info['type']) : FALSE;
  }

  public function query($string = FALSE) {
    if (!$string) {
      return FALSE;
    }

    return db_select('purl', 'p')
      ->fields('p', array('id'))
      ->condition('p.value', $string)
      ->execute()
      ->fetchField();
  }

  public function get($variable = NULL) {
    return isset($this->_processor_info[$variable]) ? $this->_processor_info[$variable] : FALSE;
  }

  public function method(){
    return 'domain_or_path';
  }

  public function admin_form(&$form, $id) {
  }

  public function description(){
    return t('Choose a path or domain. Paths may contain only lowercase letters, numbers, dashes and underscores. Domains must contain, at least one dot');
  }

  public function detect($q){
    return ($this->get('type') === 'domain') ?
      $this->_processor_info['url'] : (method_exists($this->_processor, 'detect') ? $this->_processor->detect($q) : $q);
  }

  public function parse($valid_values, $value){
	  return method_exists($this->_processor, 'parse') ?
      $this->_processor->parse($valid_values, $value) : FALSE;
  }

  public function adjust(&$value, $element, &$q){
    if (method_exists($this->_processor, 'adjust')) {
      $this->_processor->adjust($value, $element, $q);
    }
  }

  public function rewrite(&$path, &$options, $element){
    if (FALSE === $this->_processor) {
      $base_url = $this->base_url();
      $base = parse_url($base_url);
      $base_path = !empty($base['path']) ? $base['path'] : ''; //'/' . $GLOBALS['_GET']['q'];
      $base_scheme = !empty($base['scheme']) ? $base['scheme'] : 'http';

      $options['absolute'] = TRUE;
      $options['base_url'] = "{$base_scheme}://{$element->value}{$base_path}";
      $options['destination'] = $GLOBALS['_GET']['destination'];
    }
    else {
      if (method_exists($this->_processor, 'rewrite')) {
        // Purl Domain.
        if ($this->get('type') === 'domain') {
          $this->_processor->rewrite($path, $options, $element);
        }

        // Purl Path.
        if ($this->get('type') === 'path') {
          $options['prefix'] = FALSE;
        }
      }
    }
  }

  public function base_url() {
    global $base_url;
    $base = variable_get('purl_base_domain', $base_url);
    return !empty($base) ? $base : $base_url;
  }
}
